amachine.am_pattern API documentation

GitLab Repo

# amachine.am_pattern

View Source

     1class Pattern :
     2
     3	def __init__(self) :
     4		pass
     5
     6class DfaPattern( Pattern ) :
     7
     8	"""
     9	Class planned to implement sub-pattern analysis based on the approaches from these papers:
    10
    11	Analysis of pattern overlaps and exact computation of P-values of pattern occurrences numbers: case of Hidden Markov Models." Régnier (2014)
    12
    13	Probabilistic Arithmetic Automata and
    14	their Applications∗, Marschall (2024)
    15	"""
    16
    17	def __init__(self) :
    18		pass

class Pattern: View Source

    3class Pattern :
    4
    5	def __init__(self) :
    6		pass

class DfaPattern(Pattern): View Source

     8class DfaPattern( Pattern ) :
     9
    10	"""
    11	Class planned to implement sub-pattern analysis based on the approaches from these papers:
    12
    13	Analysis of pattern overlaps and exact computation of P-values of pattern occurrences numbers: case of Hidden Markov Models." Régnier (2014)
    14
    15	Probabilistic Arithmetic Automata and
    16	their Applications∗, Marschall (2024)
    17	"""
    18
    19	def __init__(self) :
    20		pass

Class planned to implement sub-pattern analysis based on the approaches from these papers:

Analysis of pattern overlaps and exact computation of P-values of pattern occurrences numbers: case of Hidden Markov Models." Régnier (2014)

Probabilistic Arithmetic Automata and their Applications∗, Marschall (2024)